recreate_genesis_segment

Function recreate_genesis_segment 

pub fn recreate_genesis_segment(
    owned_genesis_block: &OwnedBeaconChainBlock,
    erasure_coding: ErasureCoding,
) -> NewArchivedSegment
Re-create the genesis segment on demand.

This is a bit of a hack and is useful for deriving of the genesis beacon chain segment that is a special case since we don’t have enough data in the blockchain history itself during genesis to do the archiving.